.. xdgpspconf documentation master file, created by
   sphinx-quickstart on Fri Apr 30 19:45:30 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

######################################################################
Welcome to xdgpspconf's documentation!
######################################################################

.. toctree::
   :maxdepth: 2
   :caption: Contents:


   README
   INSTALL
   usage
   source-code-doc


############################
Indices and tables
############################

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
